Module const_size

Module const_size 

Bloom filters with compile-time-determinted parameters (size & hash count)

Structs

BloomFilter
The bloom filter is a probabilistic data structure that can be used to store a set of hashes.