Bloom filters with compile-time-determinted parameters (size & hash count)
Structs
- Bloom
Filter - The bloom filter is a probabilistic data structure that can be used to store a set of hashes.
Bloom filters with compile-time-determinted parameters (size & hash count)